===============================
facehugger
===============================

.. image:: https://badge.fury.io/py/facehugger.png
    :target: http://badge.fury.io/py/facehugger
    
.. image:: https://travis-ci.org/dnmellen/facehugger.png?branch=master
        :target: https://travis-ci.org/dnmellen/facehugger

.. image:: https://coveralls.io/repos/dnmellen/facehugger/badge.png
        :target: https://coveralls.io/r/dnmellen/facehugger

.. image:: https://pypip.in/d/facehugger/badge.png
        :target: https://crate.io/packages/facehugger?version=latest


Extracts faces from an image

* Free software: BSD license
* Documentation: http://facehugger.rtfd.org.

.. image:: https://raw.github.com/dnmellen/facehugger/master/demo.jpg
        :target: http://commons.wikimedia.org/wiki/File:Christina_Hendricks_(8050119303).jpg

Requirements
------------

* `SimpleCV <https://github.com/sightmachine/simplecv>`_

.. code-block :: bash

    # System requirements for Ubuntu
    sudo apt-get install ipython python-opencv python-scipy python-numpy python-pygame python-setuptools python-pip


Features
--------

* Extracts faces and saves the cropped images to a folder
* You can use it in your app as a library


Quickstart
----------

.. code-block :: bash

    $ sudo pip install facehugger
    $ facehugger -i /path/to/image_with_faces.jpg -o /path/to/dir_to_save_faces

Why this name?
--------------

.. image:: http://img6.joyreactor.com/pics/post/gif-Alien-Facehugger-618166.gif
        :target: http://joyreactor.com/tag/Facehugger


Did you like it?
---------------
.. image:: https://rawgithub.com/twolfson/gittip-badge/0.1.0/dist/gittip.png
    :target: https://www.gittip.com/dnmellen/
    :alt: gittip

